=== modified file 'drizzled/execute.cc'
--- drizzled/execute.cc	2011-08-05 12:55:59 +0000
+++ drizzled/execute.cc	2011-08-10 17:58:23 +0000
@@ -35,12 +35,7 @@
 {
 }
 
-void Execute::run(const char *arg, size_t length)
-{
-  run(std::string(arg, length));
-}
-
-void Execute::run(const std::string &execution_string, sql::ResultSet &result_set)
+void Execute::run(str_ref execution_string, sql::ResultSet &result_set)
 {
   if (not _session.isConcurrentExecuteAllowed())
   {
@@ -84,7 +79,8 @@
     {
       boost::this_thread::restore_interruption dl(_session.getThreadInterupt());
       
-      try {
+      try 
+      {
         thread->join();
       }
       catch(boost::thread_interrupted const&)
@@ -101,7 +97,7 @@
   }
 }
 
-void Execute::run(const std::string &execution_string)
+void Execute::run(str_ref execution_string)
 {
   if (not _session.isConcurrentExecuteAllowed())
   {
@@ -143,7 +139,8 @@
     {
       boost::this_thread::restore_interruption dl(_session.getThreadInterupt());
 
-      try {
+      try 
+      {
         thread->join();
       }
       catch(boost::thread_interrupted const&)

=== modified file 'drizzled/execute.h'
--- drizzled/execute.h	2011-04-13 12:46:37 +0000
+++ drizzled/execute.h	2011-08-10 17:58:23 +0000
@@ -32,9 +32,8 @@
 public:
   Execute(Session&, bool wait_arg);
 
-  void run(const std::string&);
-  void run(const char*, size_t);
-  void run(const std::string&, sql::ResultSet&);
+  void run(str_ref);
+  void run(str_ref, sql::ResultSet&);
 
   Session &session()
   {

=== modified file 'drizzled/plugin/client/concurrent.h'
--- drizzled/plugin/client/concurrent.h	2011-08-10 16:48:48 +0000
+++ drizzled/plugin/client/concurrent.h	2011-08-10 17:58:23 +0000
@@ -105,7 +105,7 @@
   virtual bool haveError(void) { return false; }
   virtual bool wasAborted(void) { return false; }
 
-  void pushSQL(const std::string &arg)
+  void pushSQL(str_ref arg)
   {
     ::drizzled::error_t err_msg;
     ::drizzled::execute::Context context(arg.data(), arg.size(), err_msg);

=== modified file 'drizzled/plugin/null_client.h'
--- drizzled/plugin/null_client.h	2011-08-10 16:48:48 +0000
+++ drizzled/plugin/null_client.h	2011-08-10 17:58:23 +0000
@@ -34,7 +34,7 @@
 class NullClient: public Client
 {
   typedef std::vector<char> Bytes;
-  typedef std::queue <Bytes> Queue;
+  typedef std::queue<Bytes> Queue;
   Queue to_execute;
   bool is_dead;
   Bytes packet_buffer;
@@ -54,18 +54,13 @@
 
   virtual bool readCommand(char **packet, uint32_t& packet_length)
   {
-    while(not to_execute.empty())
+    while (not to_execute.empty())
     {
       Queue::value_type next= to_execute.front();
-      packet_buffer.resize(next.size());
-      memcpy(&packet_buffer[0], &next[0], next.size());
-
+      packet_buffer.assign(next.begin(), next.end());
       *packet= &packet_buffer[0];
-
       packet_length= next.size();
-
       to_execute.pop();
-
       return true;
     }
 
@@ -75,7 +70,6 @@
       packet_length= 1;
       *packet= &packet_buffer[0];
       is_dead= true;
-
       return true;
     }
 
@@ -83,8 +77,8 @@
     return false;
   }
 
-  virtual void sendOK(void) {}
-  virtual void sendEOF(void) {}
+  virtual void sendOK() {}
+  virtual void sendEOF() {}
   virtual void sendError(const drizzled::error_t, const char*) {}
   virtual void sendFields(List<Item>&) {}
   virtual void store(Field *) {}
@@ -98,10 +92,10 @@
   virtual void store(const char*) {}
   virtual void store(const char*, size_t) {}
   virtual void store(str_ref) {}
-  virtual bool haveError(void) { return false; }
-  virtual bool wasAborted(void) { return false; }
+  virtual bool haveError() { return false; }
+  virtual bool wasAborted() { return false; }
 
-  void pushSQL(const std::string &arg)
+  void pushSQL(str_ref arg)
   {
     Bytes byte;
     typedef boost::tokenizer<boost::escaped_list_separator<char> > Tokenizer;
@@ -111,7 +105,7 @@
     {
       byte.resize(iter->size() +1); // +1 for the COM_QUERY
       byte[0]= COM_QUERY;
-      memcpy(&byte[1], iter->c_str(), iter->size());
+      memcpy(&byte[1], iter->data(), iter->size());
       to_execute.push(byte);
     }
   }

=== modified file 'drizzled/statement/execute.cc'
--- drizzled/statement/execute.cc	2011-07-25 14:24:19 +0000
+++ drizzled/statement/execute.cc	2011-08-10 17:58:23 +0000
@@ -37,7 +37,7 @@
 namespace statement {
 
 Execute::Execute(Session *in_session,
-                 drizzled::execute_string_t to_execute_arg,
+                 execute_string_t to_execute_arg,
                  bool is_quiet_arg,
                  bool is_concurrent_arg,
                  bool should_wait_arg) :
@@ -121,7 +121,7 @@
     }
 
     drizzled::Execute executer(session(), should_wait);
-    executer.run(to_execute.str, to_execute.length);
+    executer.run(to_execute);
   }
   else // Non-concurrent run.
   {

=== modified file 'plugin/utility_functions/execute.cc'
--- plugin/utility_functions/execute.cc	2011-04-13 12:46:37 +0000
+++ plugin/utility_functions/execute.cc	2011-08-10 17:58:23 +0000
@@ -30,17 +30,13 @@
 bool Execute::val_bool()
 {
   drizzled::String *res= args[0]->val_str(&_res);
-
   if (not res or not res->length())
   {
     null_value= true;
     return false;
   }
-
-  execute.run(res->c_str(), res->length());
-
+  execute.run(*res);
   null_value= false;
-
   return true;
 }
 

